import pytest

from toarstats.trends.utils import (
    calculate_anomalies, calculate_seasonal_cycle, moving_block_bootstrap
)


def test_calculate_seasonal_cycle_monthly_data(mean_data):
    seasonal_cycle = calculate_seasonal_cycle(
        mean_data.rename(columns={"values": "value"})
    )
    assert seasonal_cycle.index.tolist() == list(range(12))


def test_calculate_anomalies_monthly_data(mean_data):
    anomalies_series = calculate_anomalies(
        mean_data.rename(columns={"values": "value"})
    )
    assert anomalies_series.columns.tolist() == ["value", "datetime"]
    assert anomalies_series["datetime"].tolist() == sorted(
        anomalies_series["datetime"].tolist()
    )


@pytest.mark.slow
def test_moving_block_bootstrap_quant_reg(mean_data):
    anomalies_series = calculate_anomalies(
        mean_data.rename(columns={"values": "value"})
    )
    mbb = moving_block_bootstrap("quant_reg", anomalies_series, 0.5)
    assert len(mbb) == 1000


def test_moving_block_bootstrap_quant_reg_few_samples(mean_data):
    anomalies_series = calculate_anomalies(
        mean_data.rename(columns={"values": "value"})
    )
    mbb = moving_block_bootstrap("quant_reg", anomalies_series, 0.5, 50)
    assert len(mbb) == 50


@pytest.mark.slow
def test_moving_block_bootstrap_ols(mean_data):
    anomalies_series = calculate_anomalies(
        mean_data.rename(columns={"values": "value"})
    )
    mbb = moving_block_bootstrap("OLS", anomalies_series)
    assert len(mbb) == 1000


def test_moving_block_bootstrap_ols_few_samples(mean_data):
    anomalies_series = calculate_anomalies(
        mean_data.rename(columns={"values": "value"})
    )
    mbb = moving_block_bootstrap("OLS", anomalies_series, num_samples=50)
    assert len(mbb) == 50
